# LXC Provider:

**NOTE: This will only work on Ubuntu 16.04 or newer**

Assuming that you installed the dependencies and that you are running Ubuntu16.04+ as your host you should be able to run

```
rambo up -p lxc
rambo ssh
```
